@@ -3,7 +3,7 @@ package App::paperback;
 use v5.10;
 use strict;
 # use warnings;
-our $VERSION = "1.08";
+our $VERSION = "1.09";
 
 my ($GinFile, $GpageObjNr, $Groot, $Gpos, $GobjNr, $Gstream, $GoWid, $GoHei);
 my (@Gkids, @Gcounts, @GformBox, @Gobject, @Gparents, @Gto_be_created);
@@ -279,7 +279,7 @@ sub writePageStream {
 ##########################################################
 sub writePageResources {
 ##########################################################
-  my $parent = $_[0]; my $resourceObject = $_[1];
+  my ($parent, $resourceObject) = ($_[0], $_[1]);
   $Gpos += syswrite $OUT_FILE, "${GpageObjNr} 0 obj<</Type/Page/Parent ${parent} 0 "
     . "R/Contents ${GobjNr} 0 R/Resources ${resourceObject} 0 R>>endobj\n";
   push @{ $Gkids[0] }, $GpageObjNr;
@@ -407,8 +407,8 @@ sub writeEndNode {
 ##########################################################
 sub calcRotateMatrix {
 ##########################################################
-  my $x = $_[0]; my $y = $_[1]; my $rotate = $_[2];
-  my $str = "1 0 0 1 ${x} ${y} cm\n";
+  my $rotate = $_[2];
+  my $str = "1 0 0 1 $_[0] $_[1] cm\n";
 
   if ($rotate) {
     my $upperX = 0; my $upperY = 0;
@@ -454,7 +454,7 @@ sub getRootFromXrefSection {
   ($incoming_line, $qty, $i) = extractContent();
 
   while ($qty) {
-    for ( my $l = 1 ; $l <= $qty ; ++$l ) {
+    for (1..$qty) {
       sysread $IN_FILE, $incoming_line, 20;
       if ( $incoming_line =~ m'^\s?(\d+) \d+ (\w)\s*' ) {
         $GoldObject{$i} = int($1) unless $2 ne "n" or exists $GoldObject{$i};
@@ -466,7 +466,7 @@ sub getRootFromXrefSection {
 
   while ($incoming_line) {
     $buf .= $incoming_line;
-    $rooty = $1 if $buf =~ m'\/Root\s+(\d+)\s{1,2}\d+\s{1,2}R's;
+    $rooty = $1 if $buf =~ m'\/Root\s+(\d+)\s+\d+\s+R's;
     last if $rooty;
     sysread $IN_FILE, $incoming_line, 30;
   }
@@ -493,12 +493,11 @@ sub getObject {
 ##########################################################
 sub writeToBeCreated {
 ##########################################################
-  my $elObje = $_[0];
-  my ($out_line, $part, $strPos);
+  my ($elObje, $out_line, $part, $strPos, $old_one, $new_one);
 
   for (@Gto_be_created) {
-    my $old_one = $_->[0];
-    my $new_one = $_->[1];
+    $old_one = $_->[0];
+    $new_one = $_->[1];
     $elObje = getObject($old_one);
     if ( $elObje =~ m'^(\d+ \d+ obj\s*<<)(.+)(>>\s*stream)'s ) {
       $part = $2;
@@ -526,7 +525,7 @@ sub getInputPageDimensions {
   my $elObje = getObject($Groot);
 
   # Find pages:
-  return "unknown" unless $elObje =~ m'/Pages\s+(\d+)\s{1,2}\d+\s{1,2}R's;
+  return "unknown" unless $elObje =~ m'/Pages\s+(\d+)\s+\d+\s+R's;
   $elObje = getObject($1);
 
   $elObje = xformObjForThisPage($elObje, 1);
@@ -537,24 +536,24 @@ sub getInputPageDimensions {
     . int($GformBox[3] / 72 * 25.4) . " mm";
 
   for ($multi) {
-  	# US 1/4 letter: 120780
-	  if ($_ > 119_780 and $_ < 121_780) {$GoWid = $DW; $GoHei = $DH; return "QT";}
-		# ISO A6: 124443
-	  if ($_ > 123_443 and $_ < 125_443) {$GoWid = $AW; $GoHei = $AH; return "A6";}
-	  # US 1/4 legal: 153720
-	  if ($_ > 152_720 and $_ < 154_720) {$GoWid = $GW; $GoHei = $GH; return "QG";}
-	  # US 1/2 Letter ("statement"): 242352
-	  if ($_ > 241_352 and $_ < 243_352) {$GoWid = $DW; $GoHei = $DH; return "HT";}
-	  # ISO A5: 249305
-	  if ($_ > 248_305 and $_ < 250_305) {$GoWid = $AW; $GoHei = $AH; return "A5";}
-	  # US 1/2 legal: 308448
-	  if ($_ > 307_448 and $_ < 309_448) {$GoWid = $GW; $GoHei = $GH; return "HG";}
-	  # US letter: 484704
-	  if ($_ > 483_704 and $_ < 485_704) {return "USletter, ${measuresInMm}"; } 
-	  # ISO A4: 500395
-	  if ($_ > 499_395 and $_ < 501_395) {return "A4, ${measuresInMm}"; }
-	  # US legal: 616896
-	  if ($_ > 615_896 and $_ < 617_896) {return "USlegal, ${measuresInMm}";}
+    # US 1/4 letter: 120780
+    if ($_ > 119_780 and $_ < 121_780) {$GoWid = $DW; $GoHei = $DH; return "QT";}
+    # ISO A6: 124443
+    if ($_ > 123_443 and $_ < 125_443) {$GoWid = $AW; $GoHei = $AH; return "A6";}
+    # US 1/4 legal: 153720
+    if ($_ > 152_720 and $_ < 154_720) {$GoWid = $GW; $GoHei = $GH; return "QG";}
+    # US 1/2 Letter ("statement"): 242352
+    if ($_ > 241_352 and $_ < 243_352) {$GoWid = $DW; $GoHei = $DH; return "HT";}
+    # ISO A5: 249305
+    if ($_ > 248_305 and $_ < 250_305) {$GoWid = $AW; $GoHei = $AH; return "A5";}
+    # US 1/2 legal: 308448
+    if ($_ > 307_448 and $_ < 309_448) {$GoWid = $GW; $GoHei = $GH; return "HG";}
+    # US letter: 484704
+    if ($_ > 483_704 and $_ < 485_704) {return "USletter, ${measuresInMm}"; } 
+    # ISO A4: 500395
+    if ($_ > 499_395 and $_ < 501_395) {return "A4, ${measuresInMm}"; }
+    # US legal: 616896
+    if ($_ > 615_896 and $_ < 617_896) {return "USlegal, ${measuresInMm}";}
   }
   return "unknown, ${measuresInMm}";
 }
@@ -571,7 +570,7 @@ sub getPage {
 
   # Find pages:
   die "[!] Didn't find Pages section in '${GinFile}' - aborting" 
-    unless $elObje =~ m'/Pages\s+(\d+)\s{1,2}\d+\s{1,2}R's;
+    unless $elObje =~ m'/Pages\s+(\d+)\s+\d+\s+R's;
   $elObje = getObject($1);
 
   $elObje = xformObjForThisPage($elObje, $pagenumber);
@@ -579,7 +578,7 @@ sub getPage {
 
   $reference = writeRes($elObje, $formRes, $formCont);
 
-  writeToBeCreated($elObje);
+  writeToBeCreated();
 
   return $reference;
 }
@@ -610,15 +609,15 @@ sub writeRes {
 ##########################################################
 sub xformObjForThisPage {
 ##########################################################
-  my $elObje = $_[0]; my $pagenumber = $_[1];
-  my ( $vector, @pageObj, @pageObjBackup, $pageAccumulator);
+  my ($elObje, $pagenumber) = ($_[0], $_[1]);
+  my ($vector, @pageObj, @pageObjBackup, $pageAccumulator);
 
   return 0 unless $elObje =~ m'/Kids\s*\[([^\]]+)'s;
   $vector = $1;
 
   $pageAccumulator = 0;
 
-  push @pageObj, $1 while $vector =~ m'(\d+)\s{1,2}\d+\s{1,2}R'gs;
+  push @pageObj, $1 while $vector =~ m'(\d+)\s+\d+\s+R'gs;
   while ( $pageAccumulator < $pagenumber ) {
     @pageObjBackup = @pageObj;
     undef @pageObj;
@@ -629,7 +628,7 @@ sub xformObjForThisPage {
           $pageAccumulator += $1;
         } else {
           $vector = $1 if $elObje =~ m'/Kids\s*\[([^\]]+)'s ;
-          push @pageObj, $1 while $vector =~ m'(\d+)\s{1,2}\d+\s{1,2}R'gs;
+          push @pageObj, $1 while $vector =~ m'(\d+)\s+\d+\s+R'gs;
           last;
         }
       } else {
@@ -657,7 +656,7 @@ sub getResources {
 
   if ( $obj =~ m'/Contents\s+(\d+)'s ) {
     $formCont = $1;
-  } elsif ( $obj =~ m'/Contents\s*\[\s*(\d+)\s{1,2}\d+\s{1,2}R\s*\]'s ) {
+  } elsif ( $obj =~ m'/Contents\s*\[\s*(\d+)\s+\d+\s+R\s*\]'s ) {
     $formCont = $1;
   }
 
@@ -674,7 +673,7 @@ sub getResourcesFromObj {
   my $resources;
 
   if ( $obj =~ m'^(.+/Resources)'s ) {
-    return $1 if $obj =~ m'Resources(\s+\d+\s{1,2}\d+\s{1,2}R)'s; # Reference (95%)
+    return $1 if $obj =~ m'Resources(\s+\d+\s+\d+\s+R)'s; # Reference (95%)
     # The resources are a dictionary. The whole is copied (morfologia.pdf):
     my $k;
     ( undef, $obj ) = split /\/Resources/, $obj;
@@ -711,7 +710,7 @@ sub openInputFile {
 
   # Find pages
   return 0 unless eval { $elObje = getObject($Groot); 1; };
-  if ( $elObje =~ m'/Pages\s+(\d+)\s{1,2}\d+\s{1,2}R's ) {
+  if ( $elObje =~ m'/Pages\s+(\d+)\s+\d+\s+R's ) {
     $elObje = getObject($1);
     return ($1, $inputPageSize) if $elObje =~ m'/Count\s+(\d+)'s;
   }
@@ -732,7 +731,7 @@ sub saveOldObjects {
   for (@offset) {
     $saved = $GoldObject{$_};
     $bytes -= $saved;
-    $GoldObject{$_} = [ $saved, $bytes ] if ($_ !~ m'^xref');
+    $GoldObject{$_} = [ $saved, $bytes ] if ! m'^xref';
     $bytes = $saved;
   }
 }
@@ -747,7 +746,7 @@ sub renew_ddR_and_populate_to_be_created {
     push @Gto_be_created, [ $1, ++$GobjNr ];
     return $Gold{$1} = $GobjNr;
   };
-  $_[0] =~ s/\b(\d+)\s{1,2}\d+\s{1,2}R\b/&$xform . ' 0 R'/eg;
+  $_[0] =~ s/\b(\d+)\s+\d+\s+R\b/&$xform . ' 0 R'/eg;
   return;
 }
 
@@ -758,7 +757,7 @@ sub extractContent {
   my ($incoming_line, $qty, $i, $c);
 
   sysread $IN_FILE, $c, 1;
-  sysread $IN_FILE, $c, 1 while $c =~ m!\s!s;
+  sysread $IN_FILE, $c, 1 while $c =~ m'\s's;
   while ( (defined $c) and ($c ne "\n") and ($c ne "\r") ) {
     $incoming_line .= $c;
     sysread $IN_FILE, $c, 1;
@@ -785,7 +784,7 @@ sub openOutputFile {
   binmode $OUT_FILE;
   $Gpos = syswrite $OUT_FILE, $pdf_signature;
 
-  $GobjNr      = 2;  # Objeto reservado 1 para raíz y 2 para nodo lateral inicial
+  $GobjNr      = 2;  # Objeto reservado 1 para raíz y 2 para nodo de pág. inicial
   $Gparents[0] = 2;
 
   setInitGrState();
